diff --git a/htdocs/salaries/card.php b/htdocs/salaries/card.php
index 7f13a528f4d..b9042ca6c21 100755
--- a/htdocs/salaries/card.php
+++ b/htdocs/salaries/card.php
@@ -492,7 +492,7 @@ if ($action == 'create') {
// Bank
if (!empty($conf->banque->enabled)) {
print '
| ';
- print $form->editfieldkey('BankAccount', 'selectaccountid', '', $object, 0, 'string', '', 1).' | ';
+ print $form->editfieldkey('DefaultBankAccount', 'selectaccountid', '', $object, 0, 'string', '', 1).' | ';
print img_picto('', 'bank_account', 'class="paddingrighonly"');
$form->select_comptes($accountid, "accountid", 0, '', 1); // Affiche liste des comptes courant
print ' |
';
@@ -500,7 +500,7 @@ if ($action == 'create') {
// Type payment
print '| ';
- print $form->editfieldkey('PaymentMode', 'selectpaymenttype', '', $object, 0, 'string', '', 1).' | ';
+ print $form->editfieldkey('DefaultPaymentMode', 'selectpaymenttype', '', $object, 0, 'string', '', 1).' | ';
$form->select_types_paiements(GETPOST("paymenttype", 'aZ09'), "paymenttype", '');
print ' |
';
@@ -723,10 +723,10 @@ if ($id) {
print '| ' . $langs->trans("Amount") . ' | ' . price($object->amount, 0, $outputlangs, 1, -1, -1, $conf->currency) . ' |
';
}
// Mode of payment
print '';
print '| ';
- print $langs->trans('PaymentMode');
+ print $langs->trans('DefaultPaymentMode');
print ' | ';
if ($action != 'editmode')
print 'id.'">'.img_edit($langs->trans('SetMode'), 1).' | ';
@@ -740,11 +740,11 @@ if ($id) {
}
print ' ';
- // Bank Account
+ // Default Bank Account
if (!empty($conf->banque->enabled)) {
print '| ';
print ' |
@@ -723,10 +723,10 @@ if ($id) {
';
}
- // Mode of payment
+ // Default mode of payment
print '';
print '| ';
|